# Cyclebane

<span style="font-size:1.2em;font-style:italic;color:#5a5a5a">
  Transform directed acyclic graphs using map-reduce and groupby operations
  </br></br>
</span>

```{toctree}
---
hidden:
---

api-reference/index
developer/index
about/index
```
